# Code of Conduct

## Our Pledge

We pledge to make participation in this project a harassment-free experience for everyone,
regardless of age, body size, visible or invisible disability, ethnicity, sex characteristics,
gender identity and expression, level of experience, education, socio-economic status,
nationality, personal appearance, race, religion, or sexual identity and orientation.

## Our Standards

Examples of behavior that contributes to a positive environment include:
- being respectful and considerate
- focusing on what is best for the community and users
- giving and gracefully accepting constructive feedback

Examples of unacceptable behavior include:
- harassment, discrimination, or hateful conduct
- trolling, insults, or personal attacks
- publishing private information without explicit permission

## Enforcement

To report a Code of Conduct issue, please use a private channel when possible:
- open a **GitHub Security Advisory** (GitHub → repo → Security → Advisories → Report a vulnerability)

If you are comfortable reporting publicly, you may open a GitHub Issue instead.

Project maintainers are responsible for clarifying standards of acceptable behavior and will
take appropriate and fair corrective action in response to any instances of unacceptable behavior.

## Attribution

This Code of Conduct is adapted from the Contributor Covenant, version 2.1:
https://www.contributor-covenant.org/version/2/1/code_of_conduct.html

